about summary refs log tree commit diff
diff options
context:
space:
mode:
authorLukas Wirth <lukas@zed.dev>2025-08-07 15:12:26 +0200
committerLukas Wirth <lukas@zed.dev>2025-08-07 15:12:35 +0200
commit47cc8b75f0148b1c4f6f95571fbfda7b2d8b3e9d (patch)
treee5863cf6093a2765c8cc2be6cab27d044e22a390
parent51c6272baee4e60a525959c2fc9b96103ad5de74 (diff)
downloadrust-47cc8b75f0148b1c4f6f95571fbfda7b2d8b3e9d.tar.gz
rust-47cc8b75f0148b1c4f6f95571fbfda7b2d8b3e9d.zip
Enable warning logs by default
-rw-r--r--src/tools/rust-analyzer/crates/rust-analyzer/src/bin/main.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tools/rust-analyzer/crates/rust-analyzer/src/bin/main.rs b/src/tools/rust-analyzer/crates/rust-analyzer/src/bin/main.rs
index ab045e0bf9f..7602d379c0d 100644
--- a/src/tools/rust-analyzer/crates/rust-analyzer/src/bin/main.rs
+++ b/src/tools/rust-analyzer/crates/rust-analyzer/src/bin/main.rs
@@ -160,9 +160,9 @@ fn setup_logging(log_file_flag: Option<PathBuf>) -> anyhow::Result<()> {
 
     rust_analyzer::tracing::Config {
         writer,
         // Deliberately enable all `error` logs if the user has not set RA_LOG, as there is usually
         // useful information in there for debugging.
-        filter: env::var("RA_LOG").ok().unwrap_or_else(|| "error".to_owned()),
+        filter: env::var("RA_LOG").ok().unwrap_or_else(|| "warn".to_owned()),
         chalk_filter: env::var("CHALK_DEBUG").ok(),
         profile_filter: env::var("RA_PROFILE").ok(),
         json_profile_filter: std::env::var("RA_PROFILE_JSON").ok(),
@@ -160,9 +160,9 @@ fn setup_logging(log_file_flag: Option<PathBuf>) -> anyhow::Result<()> {
     rust_analyzer::tracing::Config {
         writer,
-        // Deliberately enable all `error` logs if the user has not set RA_LOG, as there is usually
+        // Deliberately enable all `warn` logs if the user has not set RA_LOG, as there is usually
         // useful information in there for debugging.